[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula A"}},"key":"1D5A0"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula B"}},"key":"1D5A1"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula C"}},"key":"1D5A2"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula D"}},"key":"1D5A3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula E"}},"key":"1D5A4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula F"}},"key":"1D5A5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula G"}},"key":"1D5A6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula H"}},"key":"1D5A7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula I"}},"key":"1D5A8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula J"}},"key":"1D5A9"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula K"}},"key":"1D5AA"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula L"}},"key":"1D5AB"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula M"}},"key":"1D5AC"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula N"}},"key":"1D5AD"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula O"}},"key":"1D5AE"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula P"}},"key":"1D5AF"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Q"}},"key":"1D5B0"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula R"}},"key":"1D5B1"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula S"}},"key":"1D5B2"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula T"}},"key":"1D5B3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula U"}},"key":"1D5B4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula V"}},"key":"1D5B5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula W"}},"key":"1D5B6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula X"}},"key":"1D5B7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Y"}},"key":"1D5B8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Z"}},"key":"1D5B9"},{"category":"Ll","mappings":{"default":{"default":"sans-serif a"}},"key":"1D5BA"},{"category":"Ll","mappings":{"default":{"default":"sans-serif b"}},"key":"1D5BB"},{"category":"Ll","mappings":{"default":{"default":"sans-serif c"}},"key":"1D5BC"},{"category":"Ll","mappings":{"default":{"default":"sans-serif d"}},"key":"1D5BD"},{"category":"Ll","mappings":{"default":{"default":"sans-serif e"}},"key":"1D5BE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif f"}},"key":"1D5BF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif g"}},"key":"1D5C0"},{"category":"Ll","mappings":{"default":{"default":"sans-serif h"}},"key":"1D5C1"},{"category":"Ll","mappings":{"default":{"default":"sans-serif i"}},"key":"1D5C2"},{"category":"Ll","mappings":{"default":{"default":"sans-serif j"}},"key":"1D5C3"},{"category":"Ll","mappings":{"default":{"default":"sans-serif k"}},"key":"1D5C4"},{"category":"Ll","mappings":{"default":{"default":"sans-serif l"}},"key":"1D5C5"},{"category":"Ll","mappings":{"default":{"default":"sans-serif m"}},"key":"1D5C6"},{"category":"Ll","mappings":{"default":{"default":"sans-serif n"}},"key":"1D5C7"},{"category":"Ll","mappings":{"default":{"default":"sans-serif o"}},"key":"1D5C8"},{"category":"Ll","mappings":{"default":{"default":"sans-serif p"}},"key":"1D5C9"},{"category":"Ll","mappings":{"default":{"default":"sans-serif q"}},"key":"1D5CA"},{"category":"Ll","mappings":{"default":{"default":"sans-serif r"}},"key":"1D5CB"},{"category":"Ll","mappings":{"default":{"default":"sans-serif s"}},"key":"1D5CC"},{"category":"Ll","mappings":{"default":{"default":"sans-serif t"}},"key":"1D5CD"},{"category":"Ll","mappings":{"default":{"default":"sans-serif u"}},"key":"1D5CE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif v"}},"key":"1D5CF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif w"}},"key":"1D5D0"},{"category":"Ll","mappings":{"default":{"default":"sans-serif x"}},"key":"1D5D1"},{"category":"Ll","mappings":{"default":{"default":"sans-serif y"}},"key":"1D5D2"},{"category":"Ll","mappings":{"default":{"default":"sans-serif z"}},"key":"1D5D3"}]
